@@ -96,10 +96,12 @@ public:
     double aic(const Eigen::MatrixXd &u) const;
 
     double bic(const Eigen::MatrixXd &u) const;
+    
+    double mbicv(const Eigen::MatrixXd &u, double pi) const;
 
     // Misc methods
     static std::vector <std::vector<Bicop>> make_pair_copula_store(size_t d,
-                                                                   size_t truncation_level = std::numeric_limits<size_t>::max());
+        size_t truncation_level = std::numeric_limits<size_t>::max());
 
 private:
     size_t d_;
@@ -107,7 +109,7 @@ private:
     std::vector <std::vector<Bicop>> pair_copulas_;
     double threshold_;
 
-    void check_data_dim(const Eigen::MatrixXd &data);
+    void check_data_dim(const Eigen::MatrixXd &data) const;
 
     Eigen::Matrix<size_t, Eigen::Dynamic, 1> inverse_permutation(
         const Eigen::Matrix<size_t, Eigen::Dynamic, 1> &order) const;
