@@ -36,7 +36,6 @@ double calculate_criterion(const Eigen::Matrix<double, Eigen::Dynamic, 2>& data,
 Eigen::MatrixXd calculate_criterion_matrix(const Eigen::MatrixXd &data,
                                            std::string tree_criterion);
 
-double calculate_gic(double loglik, double npars, int n);
 
 // boost::graph represenation of a vine tree
 struct VertexProperties
@@ -97,6 +96,8 @@ protected:
     void select_tree(size_t t);
 
     virtual void finalize(size_t trunc_lvl) = 0;
+    
+    double get_mbicv_of_tree(size_t t);
 
     double get_loglik_of_tree(size_t t);
 
@@ -107,11 +108,12 @@ protected:
     void print_pair_copulas_of_tree(size_t);
 
     std::vector<double> get_thresholded_crits();
+    
+    void initialize_new_fit(const Eigen::MatrixXd &data);
 
     void set_current_fit_as_opt();
 
-    void initialize_new_fit(const Eigen::MatrixXd &data);
-
+    
     virtual void add_allowed_edges(VineTree &tree) = 0;
 
     Eigen::MatrixXd get_pc_data(size_t v0, size_t v1, const VineTree &tree);
@@ -129,6 +131,7 @@ protected:
     // for sparse selction
     std::vector<VineTree> trees_opt_;
     double threshold_;
+    double psi0_; // initial prior probability for mbicv
 
 private:
     double get_next_threshold(std::vector<double> &thresholded_crits);
@@ -154,6 +157,8 @@ private:
     double get_tree_loglik(const VineTree &tree);
 
     double get_tree_npars(const VineTree &tree);
+    
+    size_t get_num_non_indeps_of_tree(size_t t);
 
     std::string get_pc_index(const EdgeIterator &e, const VineTree &tree);
 };
